@@ -20,7 +20,7 @@ if on_rtd:
     os.environ['PARFIVE_HIDE_PROGRESS'] = 'True'
 
 # -- Check for dependencies ----------------------------------------------------
-from sunpy.util import missing_dependencies_by_extra  # NOQA: E402
+from sunpy.util import missing_dependencies_by_extra
 
 missing_requirements = missing_dependencies_by_extra("sunpy")["docs"]
 if missing_requirements:
@@ -30,17 +30,15 @@ if missing_requirements:
     )
     sys.exit(1)
 
-from matplotlib import MatplotlibDeprecationWarning  # NOQA: E402
-# -- Non stdlib imports --------------------------------------------------------
-from ruamel.yaml import YAML  # NOQA
-from sphinx_gallery.sorting import ExplicitOrder  # NOQA
-from sunpy_sphinx_theme import PNG_ICON  # NOQA: E402
+from matplotlib import MatplotlibDeprecationWarning
+from ruamel.yaml import YAML
+from sphinx_gallery.sorting import ExplicitOrder
+from sunpy_sphinx_theme import PNG_ICON
 
-from astropy.utils.exceptions import AstropyDeprecationWarning  # NOQA: E402
+from astropy.utils.exceptions import AstropyDeprecationWarning
 
-import sunpy  # NOQA: E402
-from sunpy import __version__  # NOQA: E402
-from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyPendingDeprecationWarning  # NOQA: E402
+import sunpy
+from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyPendingDeprecationWarning
 
 # -- Project information -------------------------------------------------------
 project = 'sunpy'
@@ -48,18 +46,19 @@ author = 'The SunPy Community'
 copyright = f'{datetime.datetime.now().year}, {author}'
 
 # Register remote data option with doctest
-import doctest  # NOQA: E402
+import doctest
 
 REMOTE_DATA = doctest.register_optionflag('REMOTE_DATA')
 
 # The full version, including alpha/beta/rc tags
+from sunpy import __version__
+
 release = __version__
 sunpy_version = Version(__version__)
 is_release = not(sunpy_version.is_prerelease or sunpy_version.is_devrelease)
 
 # We want to make sure all the following warnings fail the build
 warnings.filterwarnings("error", category=SunpyDeprecationWarning)
-warnings.filterwarnings("ignore", message='The sunpy.database module is no longer actively maintained', category=SunpyDeprecationWarning)
 warnings.filterwarnings("error", category=SunpyPendingDeprecationWarning)
 warnings.filterwarnings("error", category=MatplotlibDeprecationWarning)
 warnings.filterwarnings("error", category=AstropyDeprecationWarning)
@@ -70,19 +69,24 @@ warnings.filterwarnings("error", category=AstropyDeprecationWarning)
 ori_level = sunpy.log.level
 sunpy.log.setLevel("DEBUG")
 
-import sunpy.data.sample  # NOQA: E402
+import sunpy.data.sample
 
 sunpy.data.sample.download_all()
 sunpy.log.setLevel(ori_level)
 
 # For the linkcheck
-linkcheck_ignore = [r"https://doi.org/\d+",
-                    r"https://element.io/\d+",
-                    r"https://github.com/\d+",
-                    r"https://docs.sunpy.org/\d+"]
+linkcheck_ignore = [
+    r"https://doi.org/\d+",
+    r"https://\w\.element\.io/",
+    # Checking all the PR URLs in the changelog takes a very long time
+    r"https://github.com/sunpy/sunpy/pull/\d+",
+    r"https://docs\.sunpy\.org",
+    r"https://inis.iaea.org/collection/NCLCollectionStore/_Public/20/062/20062491.pdf",
+    r"https://xrt.cfa.harvard.edu/",
+]
 linkcheck_anchors = False
 
-# -- General configuration -----------------------------------------------------
+# -- General configuration ---------------------------------------------------
 # sphinxext-opengraph
 ogp_image = "https://raw.githubusercontent.com/sunpy/sunpy-logo/master/generated/sunpy_logo_word.png"
 ogp_use_first_image = True
@@ -96,7 +100,7 @@ ogp_custom_meta_tags = [
 suppress_warnings = ['app.add_directive', ]
 
 # Add any Sphinx extension module names here, as strings. They can be
-# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
+# extensions coming with Sphinx (named "sphinx.ext.*") or your custom
 # ones.
 extensions = [
     'matplotlib.sphinxext.plot_directive',
@@ -125,7 +129,7 @@ extensions = [
 automodapi_toctreedirnm = "generated/api"
 
 # Add any paths that contain templates here, relative to this directory.
-# templates_path = ['_templates']
+# templates_path = ["_templates"]
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
@@ -136,14 +140,14 @@ automodapi_toctreedirnm = "generated/api"
 # directly to the root of the documentation.
 html_extra_path = ['robots.txt']
 
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
 if is_release:
     exclude_patterns.append('dev_guide/contents/*')
 
 # The suffix(es) of source filenames.
 # You can specify multiple suffix as a list of string:
-source_suffix = '.rst'
+source_suffix = ".rst"
 
 # The master toctree document.
 master_doc = 'index'
@@ -173,7 +177,8 @@ for line in open('nitpick-exceptions'):
     nitpick_ignore.append((dtype, target))
 
 
-# -- Options for intersphinx extension -----------------------------------------
+# -- Options for intersphinx extension ---------------------------------------
+
 # Example configuration for intersphinx: refer to the Python standard library.
 intersphinx_mapping = {
     "python": (
@@ -191,9 +196,8 @@ intersphinx_mapping = {
     "aiapy": ("https://aiapy.readthedocs.io/en/stable/", None),
     "asdf": ("https://asdf.readthedocs.io/en/stable/", None),
     "astropy": ("https://docs.astropy.org/en/stable/", None),
-    "astroquery": ("https://astroquery.readthedocs.io/en/latest/", None),
     "dask": ("https://docs.dask.org/en/stable/", None),
-    "drms": ("https://docs.sunpy.org/projects/drms/en/v0.6.4.post1/", None),
+    "drms": ("https://docs.sunpy.org/projects/drms/en/stable/", None),
     "hvpy": ("https://hvpy.readthedocs.io/en/latest/", None),
     "matplotlib": ("https://matplotlib.org/stable", None),
     "mpl_animators": ("https://docs.sunpy.org/projects/mpl-animators/en/stable/", None),
@@ -202,7 +206,6 @@ intersphinx_mapping = {
     "reproject": ("https://reproject.readthedocs.io/en/stable/", None),
     "skimage": ("https://scikit-image.org/docs/stable/", None),
     "spiceypy": ("https://spiceypy.readthedocs.io/en/stable/", None),
-    "sqlalchemy": ("https://docs.sqlalchemy.org/en/latest/", None),
     "sunkit_image": ("https://docs.sunpy.org/projects/sunkit-image/en/stable/", None),
     "sunkit_instruments": ("https://docs.sunpy.org/projects/sunkit-instruments/en/stable/", None),
     "zeep": ("https://docs.python-zeep.org/en/stable/", None),
@@ -244,13 +247,12 @@ hoverxref_role_types = {
 # -- Options for HTML output ---------------------------------------------------
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
-
 html_theme = "sunpy"
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-# html_static_path = ['_static']
+# html_static_path = ["_static"]
 
 # Render inheritance diagrams in SVG
 graphviz_output_format = "svg"
@@ -348,23 +350,37 @@ html_context = {
 }
 
 
-def rstjinja(app, docname, source):
+def jinja_to_rst(app, docname, source):
     """
     Render our pages as a jinja template for fancy templating goodness.
+
+    Depending on the building format, we render the page as a jinja template.
+
+    For the linkchecker, we bypass templating as it doesn't support jinja, but we
+    remove the jinja blocks so the page is still valid for checking.
     """
-    # Make sure we're outputting HTML
-    if app.builder.format != 'html':
-        return
-    files_to_render = ["reference/stability", "dev_guide/index"]
-    if docname in files_to_render:
-        print(f"Jinja rendering {docname}")
-        rendered = app.builder.templates.render_string(
-            source[0], app.config.html_context
-        )
-        source[0] = rendered
+    jinja_pages = ["reference/stability", "dev_guide/index"]
+    if app.builder.format == 'html':
+        if docname in jinja_pages:
+            print(f"Jinja rendering {docname}")
+            rendered = app.builder.templates.render_string(
+                source[0], app.config.html_context
+            )
+            source[0] = rendered
+    else:
+        if docname == "dev_guide/index":
+            # This page only has a single jinja block that renders if the docs are
+            # being built in development mode. We can simply  remove this block.
+            for to_replace in ["{% if is_development %}", "{%else%}", "{% endif %}"]:
+                source[0] = source[0].replace(to_replace, "")
+        if docname == "reference/stability":
+            # This page is a bit more complex, so we will remove the entire jinja block
+            # leaving on the starting text of the page. Luckily there are no URLs in the
+            # jinja block so this is safe.
+            source[0] = source[0].split("{")[0]
 
 
 # -- Sphinx setup --------------------------------------------------------------
 def setup(app):
-    # Generate the stability page
-    app.connect("source-read", rstjinja)
+    # Handles the templating for the jinja pages in our docs
+    app.connect("source-read", jinja_to_rst)
