@@ -10,6 +10,8 @@ import numpy as np
 import pytest
 from hypothesis import HealthCheck, given, settings
 from matplotlib.figure import Figure
+from matplotlib.transforms import Affine2D
+from packaging.version import Version
 
 import astropy.units as u
 import astropy.wcs
@@ -28,10 +30,10 @@ from sunpy.data.test import get_dummy_map_from_header, get_test_filepath
 from sunpy.image.transform import _rotation_registry
 from sunpy.map.mapbase import GenericMap
 from sunpy.map.sources import AIAMap
-from sunpy.tests.helpers import figure_test, skip_numpy2
+from sunpy.tests.helpers import figure_test
 from sunpy.time import parse_time
 from sunpy.util import SunpyUserWarning
-from sunpy.util.exceptions import SunpyMetadataWarning
+from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyMetadataWarning
 from sunpy.util.metadata import ModifiedItem
 from sunpy.util.util import fix_duplicate_notes
 from .conftest import make_simple_map
@@ -222,7 +224,7 @@ def test_std(generic_map):
 
 
 def test_unit(generic_map):
-    assert generic_map.unit == u.ct / u.s
+    assert generic_map.unit == u.DN / u.s
     generic_map.meta['bunit'] = 'not a unit'
     with pytest.warns(SunpyMetadataWarning, match='Could not parse unit string "not a unit"'):
         assert generic_map.unit is None
@@ -255,8 +257,8 @@ date_begend = date_dict['DATE-BEG'] + (date_dict['DATE-END'] - date_dict['DATE-B
 
 @pytest.mark.parametrize(("keys", "expected_date"),
                          ([['DATE-AVG', 'DATE-OBS', 'DATE-BEG', 'DATE-END'], date_dict['DATE-OBS']],
-                          [['DATE-AVG', 'DATE-BEG', 'DATE-END'], date_dict['DATE-AVG']],
-                          [['DATE-BEG', 'DATE-END'], date_begend],
+                          [['DATE-AVG', 'DATE-BEG', 'DATE-END'], date_dict['DATE-BEG']],
+                          [['DATE-BEG', 'DATE-END'], date_dict['DATE-BEG']],
                           [['DATE-BEG'], date_dict['DATE-BEG']],
                           [['DATE-END'], date_dict['DATE-END']],
                           [[], 'now']
@@ -378,12 +380,12 @@ def test_coordinate_frame(aia171_test_map):
     assert frame.observer.lat == aia171_test_map.observer_coordinate.frame.lat
     assert frame.observer.lon == aia171_test_map.observer_coordinate.frame.lon
     assert frame.observer.radius == aia171_test_map.observer_coordinate.frame.radius
-    assert frame.obstime == aia171_test_map.date
+    assert frame.obstime == aia171_test_map.reference_date
 
 
 def test_heliographic_longitude_crln(hmi_test_map):
     assert_quantity_allclose(hmi_test_map.heliographic_longitude,
-                             hmi_test_map.carrington_longitude - sun.L0(hmi_test_map.date),
+                             hmi_test_map.carrington_longitude - sun.L0(hmi_test_map.reference_date),
                              rtol=1e-3)  # A tolerance is needed because L0 is for Earth, not SDO
 
 
@@ -1498,7 +1500,15 @@ def test_contour_units(simple_map):
         assert np.all(c1 == c2)
 
 
-def test_contour_input(simple_map):
+@pytest.mark.skipif(Version(matplotlib.__version__) < Version("3.6.0"), reason="Fails on old MPL versions, the first with block raises a different error")
+def test_contour_inputs(simple_map):
+    with pytest.raises(ValueError, match='Contour levels must be increasing'):
+        simple_map.draw_contours([10, -10] * u.dimensionless_unscaled)
+
+    with pytest.raises(ValueError, match=r'The provided level \(1000.0\) is not smaller than the maximum data value \(8\)'):
+        simple_map.draw_contours(1000 * u.dimensionless_unscaled, fill=True)
+
+
     simple_map.meta['bunit'] = 'm'
 
     with pytest.raises(TypeError, match='The levels argument has no unit attribute'):
@@ -1645,9 +1655,36 @@ def test_rotation_rect_pixelated_data(aia171_test_map):
     rect_rot_map = rect_map.rotate(30 * u.deg)
     rect_rot_map.peek()
 
+@pytest.mark.remote_data
+@figure_test
+def test_draw_contours_with_transform(sample_171, sample_hmi):
+    aia_map = sunpy.map.Map(sample_171)
+    hmi_map = sunpy.map.Map(sample_hmi)
+    fig = plt.figure(figsize=(16, 4))
+
+    # Panel 1: Implicit transform
+    ax1 = fig.add_subplot(1, 3, 1, projection=aia_map)
+    aia_map.plot(axes=ax1, clip_interval=(1, 99.99)*u.percent)
+    hmi_map.draw_contours([-10, 10]*u.percent)
+    ax1.set_title('Default, correct behavior')
+
+    # Panel 2: Explicit transform
+    ax2 = fig.add_subplot(1, 3, 2, projection=aia_map)
+    aia_map.plot(axes=ax2, clip_interval=(1, 99.99)*u.percent)
+    hmi_map.draw_contours([-10, 10]*u.percent, transform=ax2.get_transform(hmi_map.wcs))
+    ax2.set_title('Explicitly specifying the correct transform')
+
+    # Panel 3: Explicit transform with wacky rotation
+    ax3 = fig.add_subplot(1, 3, 3, projection=aia_map)
+    rotate_transform = Affine2D().rotate_deg_around(512, 512, 90)
+    composite_transform = rotate_transform + ax3.get_transform(hmi_map.wcs)
+    aia_map.plot(axes=ax3, clip_interval=(1, 99.99)*u.percent)
+    hmi_map.draw_contours([-10, 10]*u.percent, transform=composite_transform)
+    ax3.set_title('Contours rotated by 90 deg CCW')
+
+    return fig
 
 @pytest.mark.parametrize('method', _rotation_registry.keys())
-@skip_numpy2
 @figure_test
 def test_derotating_nonpurerotation_pcij(aia171_test_map, method):
     # The following map has a a PCij matrix that is not a pure rotation
@@ -1675,12 +1712,10 @@ def check_arithmetic_value_and_units(map_new, data_expected):
 
 
 @pytest.mark.parametrize('value', [
-    10 * u.ct,
-    10 * u.mct,
-    u.Quantity([10], u.ct),
-    u.Quantity(np.random.rand(128), u.ct),
-    u.Quantity(np.random.rand(128, 128), u.ct),
-    u.Quantity(np.random.rand(128, 128), u.mct),
+    10 * u.DN,
+    u.Quantity([10], u.DN),
+    u.Quantity(np.random.rand(128), u.DN),
+    u.Quantity(np.random.rand(128, 128), u.DN),
 ])
 def test_map_arithmetic_addition_subtraction(aia171_test_map, value):
     new_map = aia171_test_map + value
@@ -1694,10 +1729,10 @@ def test_map_arithmetic_addition_subtraction(aia171_test_map, value):
 
 
 @pytest.mark.parametrize('value', [
-    10 * u.ct,
-    u.Quantity([10], u.ct),
-    u.Quantity(np.random.rand(128), u.ct),
-    u.Quantity(np.random.rand(128, 128), u.ct),
+    10 * u.s,
+    u.Quantity([10], u.s),
+    u.Quantity(np.random.rand(128), u.s),
+    u.Quantity(np.random.rand(128, 128), u.s),
     10.0,
     np.random.rand(128),
     np.random.rand(128, 128),
@@ -1734,14 +1769,20 @@ def test_map_arithmetic_operations_raise_exceptions(aia171_test_map, value):
     with pytest.raises(TypeError):
         _ = value / aia171_test_map
 
-
-def test_parse_fits_units():
-    # Check that we parse a BUNIT of G correctly.
-    out_unit = GenericMap._parse_fits_unit("Gauss")
-    assert out_unit == u.G
-
-    out_unit = GenericMap._parse_fits_unit("G")
-    assert out_unit == u.G
+@pytest.mark.parametrize(('units_string','expected_unit'),[
+    ('Gauss', u.G),
+    ('G', u.G),
+    ('DN', u.DN),
+    ('DN/s', u.DN/u.s),
+    ('DN/pix', u.DN/u.pixel),
+    ('DN / pix', u.DN/u.pixel),
+    ('DN sr / s', u.DN*u.sr/u.s),
+    ('DN/(pix s)', u.DN/u.pixel/u.s),
+    ('counts / pixel', u.ct/u.pix),
+])
+def test_parse_fits_units(units_string, expected_unit):
+    out_unit = GenericMap._parse_fits_unit(units_string)
+    assert out_unit == expected_unit
 
 
 def test_only_cd():
@@ -1767,7 +1808,23 @@ def test_only_cd():
     np.testing.assert_allclose(cd_map.rotation_matrix, np.array([[3/5, -4/5], [5/13, 12/13]]))
 
 
-def test_plot_annotate_nonboolean(aia171_test_map):
-    ax = plt.subplot(projection=aia171_test_map)
-    with pytest.raises(TypeError, match="non-boolean value"):
-        aia171_test_map.plot(ax)
+def test_plot_deprecated_positional_args(aia171_test_map):
+    with pytest.warns(SunpyDeprecationWarning, match=r"Pass annotate=True as keyword args"):
+        aia171_test_map.plot(True)
+
+    with pytest.warns(SunpyDeprecationWarning, match=r"Pass annotate=interpolation as keyword args."):
+        with pytest.raises(TypeError, match="non-boolean value"):
+            aia171_test_map.plot('interpolation')
+
+    with pytest.warns(SunpyDeprecationWarning, match=r"Pass annotate=interpolation, axes=True as keyword args."):
+        with pytest.raises(TypeError, match="non-boolean value"):
+            aia171_test_map.plot('interpolation', True)
+
+
+def test_submap_nan_error(aia171_test_map):
+    # See https://github.com/sunpy/sunpy/pull/7543#issuecomment-2167019208 for more context
+    coord_native = SkyCoord(0*u.arcsec, 0*u.arcsec, frame=aia171_test_map.coordinate_frame)
+    aia171_test_map.submap(coord_native, width=1000*u.arcsec, height=1000*u.arcsec)
+    coord_other = SkyCoord(0*u.arcsec, 0*u.arcsec, frame='helioprojective', observer='earth', obstime=aia171_test_map.date)
+    with pytest.raises(ValueError, match="The provided input coordinates to"):
+        aia171_test_map.submap(coord_other, width=1000*u.arcsec, height=1000*u.arcsec)
