@@ -1,10 +1,6 @@
-# Author:   Michael Malocha <mjm159@humboldt.edu>
-# Last Edit:  August 10th, 2013
-#
-# This module was developed with funding from the GSOC 2013 summer of code
 """
-This module translates the results of a HEK query into a VSO query
-and returns the results from the VSO query to the user.
+This module translates the results of a HEK query into a VSO query and
+returns the results from the VSO query to the user.
 """
 
 import sys
@@ -12,13 +8,12 @@ import sys
 from tqdm import tqdm
 
 from astropy import units
+from astropy.utils.decorators import deprecated_renamed_argument
 
 from sunpy.net import attrs as a
 from sunpy.net import hek, vso
 from sunpy.net.hek import HEKTable
-
-__author__ = 'Michael Malocha'
-__version__ = 'Aug 10th, 2013'
+from sunpy.util.exceptions import SunpyDeprecationWarning
 
 __all__ = ['translate_results_to_query', 'vso_attribute_parse', 'H2VClient']
 
@@ -49,7 +44,7 @@ def translate_results_to_query(results):
     19
 
     >>> hek2vso.translate_results_to_query(q[0])  # doctest: +REMOTE_DATA
-    [[<sunpy.net.attrs.Time(2011-08-08 01:30:04.000, 2011-08-10 00:00:04.000)>, <sunpy.net.attrs.Source(SDO: The Solar Dynamics Observatory.) object at ...>, <sunpy.net.attrs.Instrument(HMI: Helioseismic and Magnetic Imager) object at ...>, <sunpy.net.attrs.Wavelength(6172.999999999998, 6172.999999999998, 'Angstrom')>]]
+    [[<sunpy.net.attrs.Time(2011-08-08 01:30:04.000, 2011-08-10 00:00:04.000)>, <sunpy.net.attrs.Source(SDO: The Solar Dynamics Observatory.) object at ...>, <sunpy.net.attrs.Instrument: HEK object at ...>, <sunpy.net.attrs.Wavelength(0.0, 0.0, 'Angstrom')>]]
     """
     queries = []
     if isinstance(results, HEKTable):
@@ -122,6 +117,7 @@ class H2VClient:
         self.vso_results = []
         self.num_of_records = 0
 
+    @deprecated_renamed_argument("progress", None,"6.0", warning_type=SunpyDeprecationWarning)
     def full_query(self, client_query, limit=None, progress=False):
         """
         An encompassing method that takes a HEK query and returns a VSO result
@@ -140,8 +136,10 @@ class H2VClient:
         Examples
         --------
         >>> from sunpy.net import attrs as a, hek, hek2vso
-        >>> h2v = hek2vso.H2VClient()  # doctest: +REMOTE_DATA
-        >>> q = h2v.full_query((a.Time('2011/08/09 07:23:56', '2011/08/09 12:40:29'), a.hek.EventType('FL')))  # doctest: +REMOTE_DATA
+        >>> hek2vso_client = hek2vso.H2VClient()  # doctest: +REMOTE_DATA
+        >>> query = hek2vso_client.full_query((a.Time('2011/08/09 07:00:00', '2011/08/09 07:15:00'), a.hek.EventType('FL')))  # doctest: +REMOTE_DATA
+        >>> len(query)  # doctest: +REMOTE_DATA
+        7
         """
         self._quick_clean()
         if progress:
@@ -150,8 +148,10 @@ class H2VClient:
         self.hek_results = self.hek_client.search(*client_query)
         self._quick_clean()
         return self.translate_and_query(self.hek_results,
-                                        limit=limit, progress=progress)
+                                        limit=limit)
 
+    @deprecated_renamed_argument("vso_response_format", None,"6.0", warning_type=SunpyDeprecationWarning)
+    @deprecated_renamed_argument("progress", None,"6.0", warning_type=SunpyDeprecationWarning)
     def translate_and_query(self, hek_results, limit=None, progress=False, vso_response_format="table"):
         """
         Translates HEK results, makes a VSO query, then returns the results.
@@ -168,6 +168,7 @@ class H2VClient:
             An approximate limit to the desired number of VSO results.
         progress : bool
             A flag to turn off the progress bar, defaults to "off"
+            Was never used and is now deprecated, will be removed in sunpy 7.0
 
         Examples
         --------
@@ -181,14 +182,15 @@ class H2VClient:
         >>> res = h2v.translate_and_query(q)  # doctest: +REMOTE_DATA
         """
         vso_query = translate_results_to_query(hek_results)
-
+        kwargs = {}
+        if vso_response_format != "table":
+            kwargs = {"response_format": vso_response_format}
         for query in tqdm(vso_query, unit="records"):
-            temp = self.vso_client.search(*query, response_format=vso_response_format)
+            temp = self.vso_client.search(*query, **kwargs)
             self.vso_results.append(temp)
             self.num_of_records += len(temp)
-            if limit is not None:
-                if self.num_of_records >= limit:
-                    break
+            if limit is not None and self.num_of_records >= limit:
+                break
 
         return self.vso_results
 
