@@ -7,6 +7,7 @@ from pathlib import Path
 
 import drms
 import numpy as np
+import pandas as pd
 import parfive
 from packaging.version import Version
 
@@ -67,14 +68,14 @@ class JSOCClient(BaseClient):
 
     Notes
     -----
-    The full list of ``Series`` is available through this `site <http://jsoc.stanford.edu>`_.
+    The full list of ``Series`` is available via ` this page <http://jsoc.stanford.edu/JsocSeries_DataProducts_map.html>`__.
 
     JSOC requires a validated email address, you can pass in your validated email address
     using the `~sunpy.net.jsoc.attrs.Notify` attribute. You have to register your email address
-    with JSOC beforehand `here <http://jsoc.stanford.edu/ajax/register_email.html>`_.
+    with JSOC beforehand `here <http://jsoc.stanford.edu/ajax/register_email.html>`__.
 
-    The backend of SunPy's JSOC Client uses `drms package <https://github.com/sunpy/drms>`_.
-    The tutorials can be `found here <https://docs.sunpy.org/projects/en/stable/tutorial.html>`_.
+    The backend of SunPy's JSOC Client uses `drms package <https://github.com/sunpy/drms>`__.
+    The tutorials can be :ref:`found here <sunpy-tutorial-acquiring-data-jsoc>`.
     This can be used to build complex queries, by directly inputting the query string.
 
     Examples
@@ -328,8 +329,8 @@ class JSOCClient(BaseClient):
 
         Returns
         -------
-        requests : `~drms.client.ExportRequest` object or
-                   a list of  `~drms.client.ExportRequest` objects
+        requests : `~drms.ExportRequest` object or
+                   a list of  `~drms.ExportRequest` objects
             Request Id can be accessed by requests.id
             Request status can be accessed by requests.status
         """
@@ -433,10 +434,8 @@ class JSOCClient(BaseClient):
         time.sleep(sleep/2.)
 
         for response in responses:
-            if Version(drms.__version__) >= Version('0.7.0'):
-                response.wait()
-            else:
-                response.wait(verbose=progress)
+            response.wait()
+
         return self.get_request(responses, path=path, overwrite=overwrite,
                                 progress=progress, downloader=downloader,
                                 wait=wait, max_conn=max_conn, **defaults)
@@ -450,8 +449,8 @@ class JSOCClient(BaseClient):
 
         Parameters
         ----------
-        requests : `~drms.client.ExportRequest`, `str`, `list`
-            `~drms.client.ExportRequest` objects or `str` request IDs or lists
+        requests : `~drms.ExportRequest`, `str`, `list`
+            `~drms.ExportRequest` objects or `str` request IDs or lists
             returned by `~sunpy.net.jsoc.jsoc.JSOCClient.request_data`.
         path : `str`
             Path to save data to, defaults to SunPy download dir.
@@ -544,8 +543,7 @@ class JSOCClient(BaseClient):
 
         if urls:
             if progress:
-                print_message = "{0} URLs found for download. Full request totalling {1}MB"
-                print(print_message.format(len(urls), request._d['size']))
+                log.info(f"{len(urls)} URLs found for download. Full request totaling {request._d['size']}MB")
             for aurl, fname in zip(urls, paths):
                 downloader.enqueue_file(aurl, filename=fname, max_splits=max_splits)
 
@@ -748,11 +746,16 @@ class JSOCClient(BaseClient):
             key = keywords
         log.debug(f"Running following query: {ds}")
         log.debug(f"Requesting following keywords: {key}")
-        result = client.query(ds, key=key, rec_index=is_meta)
-        if result is None or result.empty:
-            return astropy.table.Table()
+        result = client.query(ds, key=key, seg=segments_passed, rec_index=is_meta)
+        if segments_passed:
+            # DRMS returns a tuple of length 2 if there is segment information
+            query_result, segment_result = result[0], result[1]
+            query_result = pd.concat([query_result, segment_result],axis=1)
         else:
-            return astropy.table.Table.from_pandas(result)
+            query_result = result
+        if result is None or query_result.empty:
+            return astropy.table.Table()
+        return astropy.table.Table.from_pandas(query_result)
 
     @classmethod
     def _can_handle_query(cls, *query):
