@@ -2,19 +2,18 @@ import sys
 import platform
 import warnings
 from pathlib import Path
-from platform import python_version
 from functools import wraps
 from importlib.metadata import entry_points
 
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import pytest
-from packaging.version import Version
 
 import astropy
 from astropy.wcs.wcs import FITSFixedWarning
 
-import sunpy.map
+# NOTE: Do not import sunpy subpackages which have optional dependencies here,
+# this module should be importable with no extra dependencies installed.
 
 __all__ = ['skip_windows', 'skip_glymur', 'skip_ana', 'skip_cdf', 'skip_opencv', 'skip_numpy2',
            'warnings_as_errors', 'asdf_entry_points']
@@ -58,24 +57,14 @@ SKIP_NUMPY2 = numpy.__version__.startswith('2.')
 skip_windows = pytest.mark.skipif(platform.system() == "Windows", reason="Windows.")
 skip_glymur = pytest.mark.skipif(SKIP_GLYMUR, reason="Glymur can not be imported.")
 skip_ana = pytest.mark.skipif(SKIP_ANA, reason="ANA is not available.")
-if Version(python_version()) >= Version("3.10.0"):
-    asdf_entry_points = pytest.mark.skipif(
-        not entry_points().select(group="asdf.resource_mappings", name="sunpy"),
-        reason="No SunPy ASDF entry points.",
-    )
-else:
-    asdf_entry_points = pytest.mark.skipif(
-        not any(
-            [
-                enter_point.name == "sunpy"
-                for enter_point in entry_points()["asdf.resource_mappings"]
-            ]
-        ),
-        reason="No SunPy ASDF entry points.",
-    )
 skip_cdf = pytest.mark.skipif(SKIP_CDF, reason="CDFlib is not available.")
 skip_opencv = pytest.mark.skipif(SKIP_OPENCV, reason="opencv is not available.")
 skip_numpy2 = pytest.mark.skipif(SKIP_NUMPY2, reason="numpy2 breaks this test do to dependency issues.")
+asdf_entry_points = pytest.mark.skipif(
+    not entry_points().select(group="asdf.resource_mappings", name="sunpy"),
+    reason="No SunPy ASDF entry points.",
+)
+
 
 
 @pytest.fixture
@@ -145,6 +134,8 @@ def no_vso(f):
 
 
 def fix_map_wcs(smap):
+    import sunpy.map
+
     # Helper function to fix a WCS and silence the warnings
     with warnings.catch_warnings():
         warnings.filterwarnings('ignore', category=FITSFixedWarning)
